==> gitbook-commander-1.1.2.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="1.1.2"></a>
## [1.1.2](https://github.com/aqrln/gitbook-commander/compare/v1.1.1...v1.1.2) (2017-07-26)


### Bug Fixes

* **cli:** fixup "bail out if gitbook not found" ([4b05a5f](https://github.com/aqrln/gitbook-commander/commit/4b05a5f))



<a name="1.1.1"></a>
## [1.1.1](https://github.com/aqrln/gitbook-commander/compare/v1.1.0...v1.1.1) (2017-07-01)


### Bug Fixes

* **cli:** make style of URLs in help consistent ([12a5543](https://github.com/aqrln/gitbook-commander/commit/12a5543))
* **cli:** pass positional args to core correctly ([f2f95f8](https://github.com/aqrln/gitbook-commander/commit/f2f95f8))



<a name="1.1.0"></a>
# [1.1.0](https://github.com/aqrln/gitbook-commander/compare/v1.0.0...v1.1.0) (2017-06-23)


### Features

* **cli:** add "--version" option ([e7dc940](https://github.com/aqrln/gitbook-commander/commit/e7dc940))
* **cli:** bail out if gitbook not found ([12bd3ae](https://github.com/aqrln/gitbook-commander/commit/12bd3ae))
* **cli:** make help message more verbose ([3fd588b](https://github.com/aqrln/gitbook-commander/commit/3fd588b))
* **cli:** recommend commands in case of a typo ([b1c48fe](https://github.com/aqrln/gitbook-commander/commit/b1c48fe))
* **cli:** report unknown commands and options ([43b63c7](https://github.com/aqrln/gitbook-commander/commit/43b63c7))
* **cli:** show usage in help ([d2a1729](https://github.com/aqrln/gitbook-commander/commit/d2a1729))



<a name="1.0.0"></a>
# 1.0.0 (2017-06-23)


### Bug Fixes

* **cli:** don't pass the first argument to gitbook ([c526fd7](https://github.com/aqrln/gitbook-commander/commit/c526fd7))


### Features

* add "gitbook-local" executable script ([903ead2](https://github.com/aqrln/gitbook-commander/commit/903ead2))
* **cli:** bind gitbook commands to yargs ([aa117fa](https://github.com/aqrln/gitbook-commander/commit/aa117fa))
* **cli:** run gitbook commands from arg handlers ([e333311](https://github.com/aqrln/gitbook-commander/commit/e333311))

==> gitbook-commander-1.1.3.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="1.1.3"></a>
## [1.1.3](https://github.com/aqrln/gitbook-commander/compare/v1.1.2...v1.1.3) (2017-09-26)


### Bug Fixes

* **package:** update yargs to version 9.0.1 ([#4](https://github.com/aqrln/gitbook-commander/issues/4)) ([18b9303](https://github.com/aqrln/gitbook-commander/commit/18b9303))



<a name="1.1.2"></a>
## [1.1.2](https://github.com/aqrln/gitbook-commander/compare/v1.1.1...v1.1.2) (2017-07-26)


### Bug Fixes

* **cli:** fixup "bail out if gitbook not found" ([4b05a5f](https://github.com/aqrln/gitbook-commander/commit/4b05a5f))



<a name="1.1.1"></a>
## [1.1.1](https://github.com/aqrln/gitbook-commander/compare/v1.1.0...v1.1.1) (2017-07-01)


### Bug Fixes

* **cli:** make style of URLs in help consistent ([12a5543](https://github.com/aqrln/gitbook-commander/commit/12a5543))
* **cli:** pass positional args to core correctly ([f2f95f8](https://github.com/aqrln/gitbook-commander/commit/f2f95f8))



<a name="1.1.0"></a>
## [1.1.0](https://github.com/aqrln/gitbook-commander/compare/v1.0.0...v1.1.0) (2017-06-23)


### Features

* **cli:** add "--version" option ([e7dc940](https://github.com/aqrln/gitbook-commander/commit/e7dc940))
* **cli:** bail out if gitbook not found ([12bd3ae](https://github.com/aqrln/gitbook-commander/commit/12bd3ae))
* **cli:** make help message more verbose ([3fd588b](https://github.com/aqrln/gitbook-commander/commit/3fd588b))
* **cli:** recommend commands in case of a typo ([b1c48fe](https://github.com/aqrln/gitbook-commander/commit/b1c48fe))
* **cli:** report unknown commands and options ([43b63c7](https://github.com/aqrln/gitbook-commander/commit/43b63c7))
* **cli:** show usage in help ([d2a1729](https://github.com/aqrln/gitbook-commander/commit/d2a1729))



<a name="1.0.0"></a>
## [1.0.0](https://github.com/aqrln/gitbook-commander/compare/afb55fe...v1.0.0) (2017-06-23)


### Bug Fixes

* **cli:** don't pass the first argument to gitbook ([c526fd7](https://github.com/aqrln/gitbook-commander/commit/c526fd7))


### Features

* add "gitbook-local" executable script ([903ead2](https://github.com/aqrln/gitbook-commander/commit/903ead2))
* **cli:** bind gitbook commands to yargs ([aa117fa](https://github.com/aqrln/gitbook-commander/commit/aa117fa))
* **cli:** run gitbook commands from arg handlers ([e333311](https://github.com/aqrln/gitbook-commander/commit/e333311))
